@@ -108,8 +108,8 @@ class Latex2pdfa:
         :param qpdf: qpdf executable
         """
         self.script_name = __file__  # the name of the script
-        self.resources = (Path('.').parent.parent / 'resources').absolute()
-        self.binaries = (Path('.').parent.parent / 'binaries').absolute()
+        self.resources = (Path('.').parent / 'resources').absolute()
+        self.binaries = (Path('.').parent / 'binaries').absolute()
 
         self.main_tex_file = Path(main_tex_file)
         assert conformance_level in ['a', 'b', 'u']
